; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = "some_name"
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.

;-| Super Motions |--------------------------------------------------------

;------------------------
; ULTIMATE PSYCHO CRUSHER
[Command]
name = "ultpsy_x"
command = ~50$B, F, B, F, x
time = 25

[Command]
name = "ultpsy_y"
command = ~50$B, F, B, F, y
time = 25

[Command]
name = "ultpsy_z"
command = ~50$B, F, B, F, z
time = 25
;--------------------------------------------------------------------------
; 2QCF
[Command]
name = "qcfqcfr_s"
command = ~D, DF, F, D, DF, F, s
time = 25

[Command]
name = "cure"
command = ~x,x,F,a,z
time = 40

[Command]
name = "2QCF_a"
command = ~D, DF, F,D, DF, F,a
time = 25

[Command]
name = "2QCF_b"
command = ~D, DF, F,D, DF, F, b
time = 25

[Command]
name = "2QCF_c"
command = ~D, DF, F,D, DF, F, c
time = 25

[Command]
name = "2QCF_x"
command = ~D, DF, F,D, DF, F, x
time = 25

[Command]
name = "2QCF_y"
command = ~D, DF, F,D, DF, F, y
time = 25

[Command]
name = "2QCF_z"
command = ~D, DF, F,D, DF, F, z
time = 25

;-| Special Motions |------------------------------------------------------
; HCF
[Command]
name = "HCF_a"
command = ~B, DB, D, DF, F, a
time = 25

[Command]
name = "HCF_b"
command = ~B, DB, D, DF, F, b
time = 25

[Command]
name = "HCF_c"
command = ~B, DB, D, DF, F, c
time = 25

[Command]
name = "HCF_x"
command = ~B, DB, D, DF, F, x
time = 25

[Command]
name = "HCF_y"
command = ~B, DB, D, DF, F, y
time = 25

[Command]
name = "HCF_z"
command = ~B, DB, D, DF, F, z
time = 25

; CCF
[Command]
name = "CCF_a"
command = ~F, DF, D, DB, B, a
time = 25

[Command]
name = "CCF_a"
command = ~F, DF, D, DB, B, b
time = 25

[Command]
name = "CCF_a"
command = ~F, DF, D, DB, B, c
time = 25

[Command]
name = "CCF_x"
command = ~F, DF, D, DB, B, x
time = 25

[Command]
name = "CCF_y"
command = ~F, DF, D, DB, B, y
time = 25

[Command]
name = "CCF_z"
command = ~F, DF, D, DB, B, z
time = 25
;-----------------
; QCF
[Command]
name = "QCF_a"
command = ~D, DF, F, a
time = 15

[Command]
name = "QCF_b"
command = ~D, DF, F, b
time = 15

[Command]
name = "QCF_c"
command = ~D, DF, F, c
time = 15

[Command]
name = "QCF_x"
command = ~D, DF, F, x
time = 15

[Command]
name = "QCF_y"
command = ~D, DF, F, y
time = 15

[Command]
name = "QCF_z"
command = ~D, DF, F, z
time = 15

;-----------------
; QCB
[Command]
name = "QCB_a"
command = ~D, DB, B, a

[Command]
name = "QCB_b"
command = ~D, DB, B, b

[Command]
name = "QCB_c"
command = ~D, DB, B, c

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

[Command]
name = "QCB_z"
command = ~D, DB, B, z

;-----------------
 Uppercut
[Command]
name = "uppercut_a"
command = ~F, D, DF, a

[Command]
name = "uppercut_b"
command = ~F, D, DF, b

[Command]
name = "uppercut_c"
command = ~F, D, DF, c

[Command]
name = "uppercut_x"
command = ~F, D, DF, x

[Command]
name = "uppercut_y"
command = ~F, D, DF, y

[Command]
name = "uppercut_z"
command = ~F, D, DF, z

[Command] 
name = "Teleport_x"
command = ~B, D, DB, x
[Command] 
name = "Teleport_a"
command = ~B, D, DB, a
[Command] 
name = "Teleport_y"
command = ~B, D, DB, y
[Command] 
name = "Teleport_b"
command = ~B, D, DB, b
[Command] 
name = "Teleport_z"
command = ~B, D, DB, z
[Command] 
name = "Teleport_c"
command = ~B, D, DB, c
;--------------------
;Charge_Down_up

[Command]
name = "chargedownup_a"
command = ~20$DB, UF, a
time = 30


[Command]
name = "chargedownup_a"
command = ~20$DB, U, a
time = 30

[Command]
name = "chargedownup_a"
command = ~20$D, U, a
time = 30

[Command]
name = "chargedownup_a"
command = ~20$DB, UF, b
time = 30


[Command]
name = "chargedownup_a"
command = ~20$DB, U, b
time = 30

[Command]
name = "chargedownup_a"
command = ~20$D, U, b
time = 30

[Command]
name = "chargedownup_a"
command = ~20$DB, UF, c
time = 30


[Command]
name = "chargedownup_a"
command = ~20$DB, U, c
time = 30

[Command]
name = "chargedownup_a"
command = ~20$D, U, c
time = 30

[Command]
name = "chargedownup_x"
command = ~20$DB, UF, x
time = 30


[Command]
name = "chargedownup_x"
command = ~20$DB, U, x
time = 30

[Command]
name = "chargedownup_x"
command = ~20$D, U, x
time = 30

[Command]
name = "chargedownup_x"
command = ~20$DB, UF, y
time = 30


[Command]
name = "chargedownup_x"
command = ~20$DB, U, y
time = 30

[Command]
name = "chargedownup_x"
command = ~20$D, U, y
time = 30

[Command]
name = "chargedownup_x"
command = ~20$DB, UF, z
time = 30


[Command]
name = "chargedownup_x"
command = ~20$DB, U, z
time = 30

[Command]
name = "chargedownup_x"
command = ~20$D, U, z
time = 30

;--------------------
;Charge_Back_fwd
[Command]
name = "chargebackfwd_a"
command = ~60$B, F, a
time = 10

[Command]
name = "chargebackfwd_b"
command = ~60$B, F, b
time = 10

[Command]
name = "chargebackfwd_c"
command = ~60$B, F, c
time = 10

[Command]
name = "chargebackfwd_x"
command = ~60$B, F, x
time = 10

[Command]
name = "chargebackfwd_y"
command = ~60$B, F, y
time = 10

[Command]
name = "chargebackfwd_z"
command = ~60$B, F, z
time = 10


;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF";Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB";Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = a+b
time = 1

[Command]
name = "ab"
command = a+b
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "fwd_a"
command = /F,a
time = 1

[Command]
name = "fwd_b"
command = /F,b
time = 1

[Command]
name = "fwd_c"
command = /F,c
time = 1

[Command]
name = "fwd_x"
command = /F,x
time = 1

[Command]
name = "fwd_y"
command = /F,y
time = 1

[Command]
name = "fwd_z"
command = /F,z
time = 1

[Command]
name = "back_a"
command = /B,a
time = 1

[Command]
name = "back_b"
command = /B,b
time = 1

[Command]
name = "back_c"
command = /B,c
time = 1

[Command]
name = "back_x"
command = /B,x
time = 1

[Command]
name = "back_y"
command = /B,y
time = 1

[Command]
name = "back_z"
command = /B,z
time = 1


[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_ab"
command = /F, a+b
time = 1

[Command]
name = "back_ab"
command = /B, a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "s"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback"
command = /$B
time = 1

[Command]
name = "holdup"
command = /$U
time = 1

[Command]
name = "holddown"
command = /$D
time = 1
;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = "command_name"
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in. 


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;Ultimate Psycho Crusher X
[State -1]
type = ChangeState
value = 4000
triggerall = command != "holddown"
triggerall = power >= 3000 ;Level 3
triggerall = statetype = S
triggerall = ctrl = 1
trigger1 = command = "ultpsy_x"
trigger2 = command = "ultpsy_y"
trigger3 = command = "ultpsy_z"
       
;===========================================================================
;---------------------------------------------------------------------------
;Psycho Crusher SFZ1
[State -1]
type = ChangeState
value = 3500
triggerall = command = "2QCF_x"
triggerall = command != "holddown"
triggerall = power >= 1000 ;Level 1
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 201
trigger4 = movecontact = 1
trigger4 = stateno = 202
trigger5 = movecontact = 1
trigger5 = stateno = 203
trigger6 = movecontact = 1
trigger6 = stateno = 204
trigger7 = movecontact = 1
trigger7 = stateno = 205
trigger8 = movecontact = 1
trigger8 = stateno = 206
trigger9 = movecontact = 1
trigger9 = stateno = 400
trigger10 = movecontact = 1
trigger10 = stateno = 401
trigger11 = movecontact = 1
trigger11 = stateno = 402
trigger12 = movecontact = 1
trigger12 = stateno = 403
trigger13 = movecontact = 1
trigger13 = stateno = 404
trigger14 = movecontact = 1
trigger14 = stateno = 405
trigger15 = movecontact = 1
trigger15 = stateno = 406
trigger16 = movecontact = 1
trigger16 = stateno = 208
trigger17 = movecontact = 1
trigger17 = stateno = 209
trigger18 = movecontact = 1
trigger18 = stateno = 207
trigger19 = movecontact = 1
trigger19 = stateno = 210

;---------------------------------------------------------------------------
;Psycho Crusher SFZ2
[State -1]
type = ChangeState
value = 3510
triggerall = command = "2QCF_y"
triggerall = command != "holddown"
triggerall = power >= 1000 ;Level 1
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 201
trigger4 = movecontact = 1
trigger4 = stateno = 202
trigger5 = movecontact = 1
trigger5 = stateno = 203
trigger6 = movecontact = 1
trigger6 = stateno = 204
trigger7 = movecontact = 1
trigger7 = stateno = 205
trigger8 = movecontact = 1
trigger8 = stateno = 206
trigger9 = movecontact = 1
trigger9 = stateno = 400
trigger10 = movecontact = 1
trigger10 = stateno = 401
trigger11 = movecontact = 1
trigger11 = stateno = 402
trigger12 = movecontact = 1
trigger12 = stateno = 403
trigger13 = movecontact = 1
trigger13 = stateno = 404
trigger14 = movecontact = 1
trigger14 = stateno = 405
trigger15 = movecontact = 1
trigger15 = stateno = 406
trigger16 = movecontact = 1
trigger16 = stateno = 208
trigger17 = movecontact = 1
trigger17 = stateno = 209
trigger18 = movecontact = 1
trigger18 = stateno = 207
trigger19 = movecontact = 1
trigger19 = stateno = 210

;---------------------------------------------------------------------------
;Psycho Crusher XVSSF
[State -1]
type = ChangeState
value = 3550
triggerall = command = "2QCF_z"
triggerall = command != "holddown"
triggerall = power >= 1000 ;Level 1
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 201
trigger4 = movecontact = 1
trigger4 = stateno = 202
trigger5 = movecontact = 1
trigger5 = stateno = 203
trigger6 = movecontact = 1
trigger6 = stateno = 204
trigger7 = movecontact = 1
trigger7 = stateno = 205
trigger8 = movecontact = 1
trigger8 = stateno = 206
trigger9 = movecontact = 1
trigger9 = stateno = 400
trigger10 = movecontact = 1
trigger10 = stateno = 401
trigger11 = movecontact = 1
trigger11 = stateno = 402
trigger12 = movecontact = 1
trigger12 = stateno = 403
trigger13 = movecontact = 1
trigger13 = stateno = 404
trigger14 = movecontact = 1
trigger14 = stateno = 405
trigger15 = movecontact = 1
trigger15 = stateno = 406
trigger16 = movecontact = 1
trigger16 = stateno = 208
trigger17 = movecontact = 1
trigger17 = stateno = 209
trigger18 = movecontact = 1
trigger18 = stateno = 207
trigger19 = movecontact = 1
trigger19 = stateno = 210
;---------------------------------------------------------------------------
;SUPER DOUBLE KNEE PRESS A
[State -1]
type = ChangeState
value = 9999
triggerall = command = "2QCF_a"
triggerall = command != "holddown"
triggerall = power >= 1000 ;Level 1
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 201
trigger4 = movecontact = 1
trigger4 = stateno = 202
trigger5 = movecontact = 1
trigger5 = stateno = 203
trigger6 = movecontact = 1
trigger6 = stateno = 204
trigger7 = movecontact = 1
trigger7 = stateno = 205
trigger8 = movecontact = 1
trigger8 = stateno = 206
trigger9 = movecontact = 1
trigger9 = stateno = 400
trigger10 = movecontact = 1
trigger10 = stateno = 401
trigger11 = movecontact = 1
trigger11 = stateno = 402
trigger12 = movecontact = 1
trigger12 = stateno = 403
trigger13 = movecontact = 1
trigger13 = stateno = 404
trigger14 = movecontact = 1
trigger14 = stateno = 405
trigger15 = movecontact = 1
trigger15 = stateno = 406
trigger16 = movecontact = 1
trigger16 = stateno = 208
trigger17 = movecontact = 1
trigger17 = stateno = 209
trigger18 = movecontact = 1
trigger18 = stateno = 207
trigger19 = movecontact = 1
trigger19 = stateno = 210
trigger20 = stateno = 89598

;===========================================================================
;SUPER DOUBLE KNEE PRESS B
[State -1]
type = ChangeState
value = 9899
triggerall = command = "2QCF_b"
triggerall = command != "holddown"
triggerall = power >= 2000 ;Level 2
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 201
trigger4 = movecontact = 1
trigger4 = stateno = 202
trigger5 = movecontact = 1
trigger5 = stateno = 203
trigger6 = movecontact = 1
trigger6 = stateno = 204
trigger7 = movecontact = 1
trigger7 = stateno = 205
trigger8 = movecontact = 1
trigger8 = stateno = 206
trigger9 = movecontact = 1
trigger9 = stateno = 400
trigger10 = movecontact = 1
trigger10 = stateno = 401
trigger11 = movecontact = 1
trigger11 = stateno = 402
trigger12 = movecontact = 1
trigger12 = stateno = 403
trigger13 = movecontact = 1
trigger13 = stateno = 404
trigger14 = movecontact = 1
trigger14 = stateno = 405
trigger15 = movecontact = 1
trigger15 = stateno = 406
trigger16 = movecontact = 1
trigger16 = stateno = 208
trigger17 = movecontact = 1
trigger17 = stateno = 209
trigger18 = movecontact = 1
trigger18 = stateno = 207
trigger19 = movecontact = 1
trigger19 = stateno = 210
trigger20 = stateno = 89598

;===========================================================================
;SUPER DOUBLE KNEE PRESS C
[State -1]
type = ChangeState
value = 9799
triggerall = command = "2QCF_c"
triggerall = command != "holddown"
triggerall = power >= 3000 ;Level 3
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 201
trigger4 = movecontact = 1
trigger4 = stateno = 202
trigger5 = movecontact = 1
trigger5 = stateno = 203
trigger6 = movecontact = 1
trigger6 = stateno = 204
trigger7 = movecontact = 1
trigger7 = stateno = 205
trigger8 = movecontact = 1
trigger8 = stateno = 206
trigger9 = movecontact = 1
trigger9 = stateno = 400
trigger10 = movecontact = 1
trigger10 = stateno = 401
trigger11 = movecontact = 1
trigger11 = stateno = 402
trigger12 = movecontact = 1
trigger12 = stateno = 403
trigger13 = movecontact = 1
trigger13 = stateno = 404
trigger14 = movecontact = 1
trigger14 = stateno = 405
trigger15 = movecontact = 1
trigger15 = stateno = 406
trigger16 = movecontact = 1
trigger16 = stateno = 208
trigger17 = movecontact = 1
trigger17 = stateno = 209
trigger18 = movecontact = 1
trigger18 = stateno = 207
trigger19 = movecontact = 1
trigger19 = stateno = 210
trigger20 = stateno = 89598

;---------------------------------------------------------------------------
;Double Knee Press a
[State -1]
type = ChangeState
value = 1500
triggerall = command = "HCF_a"
triggerall = command != "holddown"
;trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 201
trigger4 = movecontact = 1
trigger4 = stateno = 202
trigger5 = movecontact = 1
trigger5 = stateno = 203
trigger6 = movecontact = 1
trigger6 = stateno = 204
trigger7 = movecontact = 1
trigger7 = stateno = 205
trigger8 = movecontact = 1
trigger8 = stateno = 206
trigger9 = movecontact = 1
trigger9 = stateno = 400
trigger10 = movecontact = 1
trigger10 = stateno = 401
trigger11 = movecontact = 1
trigger11 = stateno = 402
trigger12 = movecontact = 1
trigger12 = stateno = 403
trigger13 = movecontact = 1
trigger13 = stateno = 404
trigger14 = movecontact = 1
trigger14 = stateno = 405
trigger15 = movecontact = 1
trigger15 = stateno = 406
trigger16 = movecontact = 1
trigger16 = stateno = 208
trigger17 = movecontact = 1
trigger17 = stateno = 209
trigger18 = movecontact = 1
trigger18 = stateno = 207
trigger19 = movecontact = 1
trigger19 = stateno = 210

;---------------------------------------------------------------------------
;Double Knee Press B
[State -1]
type = ChangeState
value = 1510
triggerall = command = "HCF_b"
triggerall = command != "holddown"
;trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 201
trigger4 = movecontact = 1
trigger4 = stateno = 202
trigger5 = movecontact = 1
trigger5 = stateno = 203
trigger6 = movecontact = 1
trigger6 = stateno = 204
trigger7 = movecontact = 1
trigger7 = stateno = 205
trigger8 = movecontact = 1
trigger8 = stateno = 206
trigger9 = movecontact = 1
trigger9 = stateno = 400
trigger10 = movecontact = 1
trigger10 = stateno = 401
trigger11 = movecontact = 1
trigger11 = stateno = 402
trigger12 = movecontact = 1
trigger12 = stateno = 403
trigger13 = movecontact = 1
trigger13 = stateno = 404
trigger14 = movecontact = 1
trigger14 = stateno = 405
trigger15 = movecontact = 1
trigger15 = stateno = 406
trigger16 = movecontact = 1
trigger16 = stateno = 208
trigger17 = movecontact = 1
trigger17 = stateno = 209
trigger18 = movecontact = 1
trigger18 = stateno = 207
trigger19 = movecontact = 1
trigger19 = stateno = 210

;---------------------------------------------------------------------------
;Double Knee Press C
[State -1]
type = ChangeState
value = 1520
triggerall = command = "HCF_c"
triggerall = command != "holddown"
;trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 201
trigger4 = movecontact = 1
trigger4 = stateno = 202
trigger5 = movecontact = 1
trigger5 = stateno = 203
trigger6 = movecontact = 1
trigger6 = stateno = 204
trigger7 = movecontact = 1
trigger7 = stateno = 205
trigger8 = movecontact = 1
trigger8 = stateno = 206
trigger9 = movecontact = 1
trigger9 = stateno = 400
trigger10 = movecontact = 1
trigger10 = stateno = 401
trigger11 = movecontact = 1
trigger11 = stateno = 402
trigger12 = movecontact = 1
trigger12 = stateno = 403
trigger13 = movecontact = 1
trigger13 = stateno = 404
trigger14 = movecontact = 1
trigger14 = stateno = 405
trigger15 = movecontact = 1
trigger15 = stateno = 406
trigger16 = movecontact = 1
trigger16 = stateno = 208
trigger17 = movecontact = 1
trigger17 = stateno = 209
trigger18 = movecontact = 1
trigger18 = stateno = 207
trigger19 = movecontact = 1
trigger19 = stateno = 210

;===========================================================================
[State -1]
type = ChangeState
value = 89999
triggerall = command = "qcfqcfr_s"
triggerall = statetype != A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;pseudo-head press
[State -1]
type = ChangeState
value = 7999
triggerall = command = "chargedownup_x"
triggerall = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 40
;---------------------------------------------------------------------------
;head press
[State -1]
type = ChangeState
value = 9599
triggerall = command = "chargedownup_a"
triggerall = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 40
;---------------------------------------------------------------------------
;Teleport X
[State -1]
type = ChangeState
value = 9499
triggerall = command = "Teleport_x"
triggerall = statetype != A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Teleport A
[State -1]
type = ChangeState
value = 9498
triggerall = command = "Teleport_a"
triggerall = statetype != A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Teleport Y
[State -1]
type = ChangeState
value = 9497
triggerall = command = "Teleport_y"
triggerall = statetype != A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Teleport B
[State -1]
type = ChangeState
value = 9496
triggerall = command = "Teleport_b"
triggerall = statetype != A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Teleport Z
[State -1]
type = ChangeState
value = 9495
triggerall = command = "Teleport_z"
triggerall = statetype != A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Teleport C
[State -1]
type = ChangeState
value = 9494
triggerall = command = "Teleport_c"
triggerall = statetype != A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Psycho field Z
[State -1]
type = ChangeState
value = 89985
triggerall = command = "CCF_z"
triggerall = command != "holddown"
triggerall = numhelper = 0
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 201
trigger4 = movecontact = 1
trigger4 = stateno = 202
trigger5 = movecontact = 1
trigger5 = stateno = 203
trigger6 = movecontact = 1
trigger6 = stateno = 204
trigger7 = movecontact = 1
trigger7 = stateno = 205
trigger8 = movecontact = 1
trigger8 = stateno = 206
trigger9 = movecontact = 1
trigger9 = stateno = 400
trigger10 = movecontact = 1
trigger10 = stateno = 401
trigger11 = movecontact = 1
trigger11 = stateno = 402
trigger12 = movecontact = 1
trigger12 = stateno = 403
trigger13 = movecontact = 1
trigger13 = stateno = 404
trigger14 = movecontact = 1
trigger14 = stateno = 405
trigger15 = movecontact = 1
trigger15 = stateno = 406
trigger16 = movecontact = 1
trigger16 = stateno = 208
trigger17 = movecontact = 1
trigger17 = stateno = 209
trigger18 = movecontact = 1
trigger18 = stateno = 207
trigger19 = movecontact = 1
trigger19 = stateno = 210

;---------------------------------------------------------------------------
;Psycho field Y
[State -1]
type = ChangeState
value = 89986
triggerall = command = "CCF_y"
triggerall = command != "holddown"
triggerall = numhelper = 0
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 201
trigger4 = movecontact = 1
trigger4 = stateno = 202
trigger5 = movecontact = 1
trigger5 = stateno = 203
trigger6 = movecontact = 1
trigger6 = stateno = 204
trigger7 = movecontact = 1
trigger7 = stateno = 205
trigger8 = movecontact = 1
trigger8 = stateno = 206
trigger9 = movecontact = 1
trigger9 = stateno = 400
trigger10 = movecontact = 1
trigger10 = stateno = 401
trigger11 = movecontact = 1
trigger11 = stateno = 402
trigger12 = movecontact = 1
trigger12 = stateno = 403
trigger13 = movecontact = 1
trigger13 = stateno = 404
trigger14 = movecontact = 1
trigger14 = stateno = 405
trigger15 = movecontact = 1
trigger15 = stateno = 406
trigger16 = movecontact = 1
trigger16 = stateno = 208
trigger17 = movecontact = 1
trigger17 = stateno = 209
trigger18 = movecontact = 1
trigger18 = stateno = 207
trigger19 = movecontact = 1
trigger19 = stateno = 210

;---------------------------------------------------------------------------
;Psycho field X
[State -1]
type = ChangeState
value = 89987
triggerall = command = "CCF_x"
triggerall = command != "holddown"
triggerall = numhelper = 0
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 201
trigger4 = movecontact = 1
trigger4 = stateno = 202
trigger5 = movecontact = 1
trigger5 = stateno = 203
trigger6 = movecontact = 1
trigger6 = stateno = 204
trigger7 = movecontact = 1
trigger7 = stateno = 205
trigger8 = movecontact = 1
trigger8 = stateno = 206
trigger9 = movecontact = 1
trigger9 = stateno = 400
trigger10 = movecontact = 1
trigger10 = stateno = 401
trigger11 = movecontact = 1
trigger11 = stateno = 402
trigger12 = movecontact = 1
trigger12 = stateno = 403
trigger13 = movecontact = 1
trigger13 = stateno = 404
trigger14 = movecontact = 1
trigger14 = stateno = 405
trigger15 = movecontact = 1
trigger15 = stateno = 406
trigger16 = movecontact = 1
trigger16 = stateno = 208
trigger17 = movecontact = 1
trigger17 = stateno = 209
trigger18 = movecontact = 1
trigger18 = stateno = 207
trigger19 = movecontact = 1
trigger19 = stateno = 210

;Psycho power z
[State -1]
type = ChangeState
value = 89988
triggerall = command = "HCF_z"
triggerall = command != "holddown"
triggerall = numhelper = 0
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 201
trigger4 = movecontact = 1
trigger4 = stateno = 202
trigger5 = movecontact = 1
trigger5 = stateno = 203
trigger6 = movecontact = 1
trigger6 = stateno = 204
trigger7 = movecontact = 1
trigger7 = stateno = 205
trigger8 = movecontact = 1
trigger8 = stateno = 206
trigger9 = movecontact = 1
trigger9 = stateno = 400
trigger10 = movecontact = 1
trigger10 = stateno = 401
trigger11 = movecontact = 1
trigger11 = stateno = 402
trigger12 = movecontact = 1
trigger12 = stateno = 403
trigger13 = movecontact = 1
trigger13 = stateno = 404
trigger14 = movecontact = 1
trigger14 = stateno = 405
trigger15 = movecontact = 1
trigger15 = stateno = 406
trigger16 = movecontact = 1
trigger16 = stateno = 208
trigger17 = movecontact = 1
trigger17 = stateno = 209
trigger18 = movecontact = 1
trigger18 = stateno = 207
trigger19 = movecontact = 1
trigger19 = stateno = 210

;---------------------------------------------------------------------------

;Psycho power y
[State -1]
type = ChangeState
value = 89989
triggerall = command = "HCF_y"
triggerall = command != "holddown"
triggerall = numhelper = 0
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 201
trigger4 = movecontact = 1
trigger4 = stateno = 202
trigger5 = movecontact = 1
trigger5 = stateno = 203
trigger6 = movecontact = 1
trigger6 = stateno = 204
trigger7 = movecontact = 1
trigger7 = stateno = 205
trigger8 = movecontact = 1
trigger8 = stateno = 206
trigger9 = movecontact = 1
trigger9 = stateno = 400
trigger10 = movecontact = 1
trigger10 = stateno = 401
trigger11 = movecontact = 1
trigger11 = stateno = 402
trigger12 = movecontact = 1
trigger12 = stateno = 403
trigger13 = movecontact = 1
trigger13 = stateno = 404
trigger14 = movecontact = 1
trigger14 = stateno = 405
trigger15 = movecontact = 1
trigger15 = stateno = 406
trigger16 = movecontact = 1
trigger16 = stateno = 208
trigger17 = movecontact = 1
trigger17 = stateno = 209
trigger18 = movecontact = 1
trigger18 = stateno = 207
trigger19 = movecontact = 1
trigger19 = stateno = 210

;---------------------------------------------------------------------------
;Psycho power X
[State -1]
type = ChangeState
value = 89990
triggerall = command = "HCF_x"
triggerall = command != "holddown"
triggerall = numhelper = 0
triggerall = numproj = 0
triggerall = p2stateno != 5300
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Fly
[State -1]
type = ChangeState
value = 89599
triggerall = command = "CCF_a"
;trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Psycho Shot X
[State -1]
type = ChangeState
value = 1000
triggerall = command = "QCF_x"
triggerall = command != "holddown"
triggerall = numhelper = 0
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 201
trigger4 = movecontact = 1
trigger4 = stateno = 202
trigger5 = movecontact = 1
trigger5 = stateno = 203
trigger6 = movecontact = 1
trigger6 = stateno = 204
trigger7 = movecontact = 1
trigger7 = stateno = 205
trigger8 = movecontact = 1
trigger8 = stateno = 206
trigger9 = movecontact = 1
trigger9 = stateno = 400
trigger10 = movecontact = 1
trigger10 = stateno = 401
trigger11 = movecontact = 1
trigger11 = stateno = 402
trigger12 = movecontact = 1
trigger12 = stateno = 403
trigger13 = movecontact = 1
trigger13 = stateno = 404
trigger14 = movecontact = 1
trigger14 = stateno = 405
trigger15 = movecontact = 1
trigger15 = stateno = 406
trigger16 = movecontact = 1
trigger16 = stateno = 208
trigger17 = movecontact = 1
trigger17 = stateno = 209
trigger18 = movecontact = 1
trigger18 = stateno = 207
trigger19 = movecontact = 1
trigger19 = stateno = 210

;---------------------------------------------------------------------------
;Psycho Shot Y
[State -1]
type = ChangeState
value = 1001
triggerall = command = "QCF_y"
triggerall = command != "holddown"
triggerall = numhelper = 0
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 201
trigger4 = movecontact = 1
trigger4 = stateno = 202
trigger5 = movecontact = 1
trigger5 = stateno = 203
trigger6 = movecontact = 1
trigger6 = stateno = 204
trigger7 = movecontact = 1
trigger7 = stateno = 205
trigger8 = movecontact = 1
trigger8 = stateno = 206
trigger9 = movecontact = 1
trigger9 = stateno = 400
trigger10 = movecontact = 1
trigger10 = stateno = 401
trigger11 = movecontact = 1
trigger11 = stateno = 402
trigger12 = movecontact = 1
trigger12 = stateno = 403
trigger13 = movecontact = 1
trigger13 = stateno = 404
trigger14 = movecontact = 1
trigger14 = stateno = 405
trigger15 = movecontact = 1
trigger15 = stateno = 406
trigger16 = movecontact = 1
trigger16 = stateno = 208
trigger17 = movecontact = 1
trigger17 = stateno = 209
trigger18 = movecontact = 1
trigger18 = stateno = 207
trigger19 = movecontact = 1
trigger19 = stateno = 210

;---------------------------------------------------------------------------
;Psycho Shot Z
[State -1]
type = ChangeState
value = 1002
triggerall = command = "QCF_z"
triggerall = command != "holddown"
triggerall = numhelper = 0
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 201
trigger4 = movecontact = 1
trigger4 = stateno = 202
trigger5 = movecontact = 1
trigger5 = stateno = 203
trigger6 = movecontact = 1
trigger6 = stateno = 204
trigger7 = movecontact = 1
trigger7 = stateno = 205
trigger8 = movecontact = 1
trigger8 = stateno = 206
trigger9 = movecontact = 1
trigger9 = stateno = 400
trigger10 = movecontact = 1
trigger10 = stateno = 401
trigger11 = movecontact = 1
trigger11 = stateno = 402
trigger12 = movecontact = 1
trigger12 = stateno = 403
trigger13 = movecontact = 1
trigger13 = stateno = 404
trigger14 = movecontact = 1
trigger14 = stateno = 405
trigger15 = movecontact = 1
trigger15 = stateno = 406
trigger16 = movecontact = 1
trigger16 = stateno = 208
trigger17 = movecontact = 1
trigger17 = stateno = 209
trigger18 = movecontact = 1
trigger18 = stateno = 207
trigger19 = movecontact = 1
trigger19 = stateno = 210

;===========================================================================
;---------------------------------------------------------------------------
;---------------------------------------------------------------------------
;RunFwd
[State -1]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Stand_Throw (close dir+b)
; Complicated? Skip the throws and look at stand_a, etc, first.
; This is disabled right now. Remove the "null;" below when you
; want to use it.
[State -1]
type = ChangeState
value = 7499
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = p2bodydist X < 20 ;Near P2
trigger1 = command = "fwd_y";p2 stand
trigger1 = stateno != 100    ;Not running
trigger1 = p2statetype = S
trigger1 = p2movetype != H
trigger2 = command = "fwd_y";p2 crouch
trigger2 = stateno != 100    ;Not running
trigger2 = p2statetype = C
trigger2 = p2movetype != H
trigger3 = command = "fwd_z";p2 stand
trigger3 = stateno != 100    ;Not running
trigger3 = p2statetype = S
trigger3 = p2movetype != H
trigger4 = command = "fwd_z";p2 crouch
trigger4 = stateno != 100    ;Not running
trigger4 = p2statetype = C
trigger4 = p2movetype != H
;---------------------------------------------------------------------------
;Air_Throw1 (close dir+b)
; This is disabled right now. Remove the "null;" below when you
; want to use it.
[State -1]
type = ChangeState
value = 950
triggerall = statetype = A
triggerall = ctrl = 1
triggerall = p2bodydist X < 9
;triggerall = p2bodydist Y > -22
;triggerall = p2bodydist Y < 22
triggerall = p2statetype = A
triggerall = p2movetype != H
trigger1 = command = "fwd_y"
trigger2 = command = "back_y"
trigger3 = command = "fwd_z"
trigger4 = command = "back_z"
;===========================================================================
;---------------------------------------------------------------------------
;Stand Z (SHIN)
[State -1]
type = ChangeState
value = 203
triggerall = command = "fwd_z"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 201
trigger4 = movecontact = 1
trigger4 = stateno = 202
trigger5 = movecontact = 1
trigger5 = stateno = 204
trigger6 = movecontact = 1
trigger6 = stateno = 205
trigger7 = movecontact = 1
trigger7 = stateno = 206
trigger8 = movecontact = 1
trigger8 = stateno = 400
trigger9 = movecontact = 1
trigger9 = stateno = 401
trigger10 = movecontact = 1
trigger10 = stateno = 402
trigger11 = movecontact = 1
trigger11 = stateno = 404
trigger12 = movecontact = 1
trigger12 = stateno = 405
trigger13 = movecontact = 1
trigger13 = stateno = 208
trigger14 = movecontact = 1
trigger14 = stateno = 209
trigger15 = movecontact = 1
trigger15 = stateno = 207
trigger16 = movecontact = 1
trigger16 = stateno = 210

;---------------------------------------------------------------------------
;Crouch Z (SHIN)
[State -1]
type = ChangeState
value = 403
triggerall = command = "holddown"
triggerall = command = "holdfwd"
triggerall = command = "z"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 400
trigger3 = movecontact = 1
trigger3 = stateno = 401
trigger4 = movecontact = 1
trigger4 = stateno = 402
trigger5 = movecontact = 1
trigger5 = stateno = 404
trigger6 = movecontact = 1
trigger6 = stateno = 405

;---------------------------------------------------------------------------
;Jump Z (SHIN)
[State -1]
type = ChangeState
value = 603
triggerall = command = "holddown"
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = p2statetype = A
trigger2 = movecontact = 1
trigger2 = stateno = 600
trigger3 = p2statetype = A
trigger3 = movecontact = 1
trigger3 = stateno = 601
trigger4 = p2statetype = A
trigger4 = movecontact = 1
trigger4 = stateno = 602
trigger5 = p2statetype = A
trigger5 = movecontact = 1
trigger5 = stateno = 604
trigger6 = p2statetype = A
trigger6 = movecontact = 1
trigger6 = stateno = 605
trigger7 = p2statetype = A
trigger7 = movecontact = 1
trigger7 = stateno = 606
trigger8 = p2statetype = A
trigger8 = movecontact = 1
trigger8 = stateno = 607
trigger9 = p2statetype = A
trigger9 = movecontact = 1
trigger9 = stateno = 608

;===========================================================================
;---------------------------------------------------------------------------
;Stand X
[State -1]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = animelem >= 4
trigger2 = stateno = 200

;---------------------------------------------------------------------------
;Stand Y
[State -1]
type = ChangeState
value = 201
triggerall = command = "y"
triggerall = command != "holddown"
triggerall = P2bodydist X > 50
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 204
trigger4 = MoveContact = 1
trigger4 = stateno = 400
trigger5 = MoveContact = 1
trigger5 = stateno = 404

;---------------------------------------------------------------------------
;Stand Z
[State -1]
type = ChangeState
value = 202
triggerall = command = "z"
triggerall = command != "holddown"
triggerall = P2bodydist X > 42
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 201
trigger4 = movecontact = 1
trigger4 = stateno = 204
trigger5 = movecontact = 1
trigger5 = stateno = 205
trigger6 = movecontact = 1
trigger6 = stateno = 208
trigger7 = movecontact = 1
trigger7 = stateno = 207
trigger8 = MoveContact = 1
trigger8 = stateno = 400
trigger9 = MoveContact = 1
trigger9 = stateno = 401
trigger10 = MoveContact = 1
trigger10 = stateno = 404
trigger11 = MoveContact = 1
trigger11 = stateno = 405
trigger12 = movecontact = 1
trigger12 = stateno = 210

;---------------------------------------------------------------------------
;Stand A
[State -1]
type = ChangeState
value = 204
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = animelem >= 4
trigger2 = stateno = 200
trigger3 = MoveContact = 1
trigger3 = stateno = 200
trigger4 = MoveContact = 1
trigger4 = stateno = 400

;---------------------------------------------------------------------------
;Stand B
[State -1]
type = ChangeState
value = 205
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = P2bodydist X > 60
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 201
trigger4 = movecontact = 1
trigger4 = stateno = 204
trigger5 = movecontact = 1
trigger5 = stateno = 207
trigger6 = MoveContact = 1
trigger6 = stateno = 400
trigger7 = MoveContact = 1
trigger7 = stateno = 401
trigger8 = MoveContact = 1
trigger8 = stateno = 404

;---------------------------------------------------------------------------
;Stand C
[State -1]
type = ChangeState
value = 206
triggerall = command = "c"
triggerall = command != "holddown"
triggerall = P2bodydist X > 40
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 201
trigger4 = movecontact = 1
trigger4 = stateno = 204
trigger5 = movecontact = 1
trigger5 = stateno = 205
trigger6 = movecontact = 1
trigger6 = stateno = 208
trigger7 = movecontact = 1
trigger7 = stateno = 207
trigger8 = movecontact = 1
trigger8 = stateno = 400
trigger9 = MoveContact = 1
trigger9 = stateno = 401
trigger10 = MoveContact = 1
trigger10 = stateno = 404
trigger11 = MoveContact = 1
trigger11 = stateno = 405

;---------------------------------------------------------------------------
;Close Y
[State -1]
type = ChangeState
value = 207
triggerall = command = "y"
triggerall = command != "holddown"
triggerall = P2bodydist X <= 50
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 204
trigger4 = MoveContact = 1
trigger4 = stateno = 400
trigger5 = MoveContact = 1
trigger5 = stateno = 404

;---------------------------------------------------------------------------
;Close B
[State -1]
type = ChangeState
value = 208
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = P2bodydist X <= 60
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 201
trigger4 = movecontact = 1
trigger4 = stateno = 204
trigger5 = movecontact = 1
trigger5 = stateno = 207
trigger6 = MoveContact = 1
trigger6 = stateno = 400
trigger7 = MoveContact = 1
trigger7 = stateno = 401
trigger8 = MoveContact = 1
trigger8 = stateno = 404

;---------------------------------------------------------------------------
;Close C
[State -1]
type = ChangeState
value = 209
triggerall = command = "c"
triggerall = command != "holddown"
triggerall = P2bodydist X <= 40
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 201
trigger4 = movecontact = 1
trigger4 = stateno = 204
trigger5 = movecontact = 1
trigger5 = stateno = 205
trigger6 = movecontact = 1
trigger6 = stateno = 208
trigger7 = movecontact = 1
trigger7 = stateno = 207
trigger8 = MoveContact = 1
trigger8 = stateno = 400
trigger9 = MoveContact = 1
trigger9 = stateno = 401
trigger10 = MoveContact = 1
trigger10 = stateno = 404
trigger11 = MoveContact = 1
trigger11 = stateno = 405

;---------------------------------------------------------------------------
;Close Z
[State -1]
type = ChangeState
value = 210
triggerall = command = "z"
triggerall = command != "holddown"
triggerall = P2bodydist X <= 42
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 201
trigger4 = movecontact = 1
trigger4 = stateno = 204
trigger5 = movecontact = 1
trigger5 = stateno = 205
trigger6 = movecontact = 1
trigger6 = stateno = 208
trigger7 = movecontact = 1
trigger7 = stateno = 207
trigger8 = MoveContact = 1
trigger8 = stateno = 400
trigger9 = MoveContact = 1
trigger9 = stateno = 401
trigger10 = MoveContact = 1
trigger10 = stateno = 404
trigger11 = MoveContact = 1
trigger11 = stateno = 405

;---------------------------------------------------------------------------
;Crouch X
[State -1]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouch Y
[State -1]
type = ChangeState
value = 401
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 400
trigger3 = movecontact = 1
trigger3 = stateno = 404
trigger4 = movecontact = 1
trigger4 = stateno = 200
trigger5 = movecontact = 1
trigger5 = stateno = 204
trigger6 = movecontact = 1
trigger6 = stateno = 207

;---------------------------------------------------------------------------
;Crouch Z
[State -1]
type = ChangeState
value = 402
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 400
trigger3 = movecontact = 1
trigger3 = stateno = 401
trigger4 = movecontact = 1
trigger4 = stateno = 404
trigger5 = movecontact = 1
trigger5 = stateno = 405
trigger6 = movecontact = 1
trigger6 = stateno = 200
trigger7 = movecontact = 1
trigger7 = stateno = 201
trigger8 = movecontact = 1
trigger8 = stateno = 204
trigger9 = movecontact = 1
trigger9 = stateno = 205
trigger10 = movecontact = 1
trigger10 = stateno = 207
trigger11 = movecontact = 1
trigger11 = stateno = 208

;---------------------------------------------------------------------------
;Aerial Rave Jump
[State -1]
type = ChangeState
value = 40
triggerall = command = "holdup"
trigger1 = movecontact = 1
trigger1 = stateno = 402

;---------------------------------------------------------------------------
;Crouch A
[State -1]
type = ChangeState
value = 404
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 400
trigger3 = movecontact = 1
trigger3 = stateno = 200
trigger4 = movecontact = 1
trigger4 = stateno = 204

;---------------------------------------------------------------------------
;Crouch B
[State -1]
type = ChangeState
value = 405
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 400
trigger3 = movecontact = 1
trigger3 = stateno = 401
trigger4 = movecontact = 1
trigger4 = stateno = 404
trigger5 = movecontact = 1
trigger5 = stateno = 200
trigger6 = movecontact = 1
trigger6 = stateno = 201
trigger7 = movecontact = 1
trigger7 = stateno = 204
trigger8 = movecontact = 1
trigger8 = stateno = 207
trigger9 = movecontact = 1
trigger9 = stateno = 208

;---------------------------------------------------------------------------
;Crouch C
[State -1]
type = ChangeState
value = 406
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = movecontact = 1
trigger2 = stateno = 400
trigger3 = movecontact = 1
trigger3 = stateno = 401
trigger4 = movecontact = 1
trigger4 = stateno = 404
trigger5 = movecontact = 1
trigger5 = stateno = 200
trigger6 = movecontact = 1
trigger6 = stateno = 201
trigger7 = movecontact = 1
trigger7 = stateno = 204
trigger8 = movecontact = 1
trigger8 = stateno = 207
trigger9 = movecontact = 1
trigger9 = stateno = 208
trigger10 = movecontact = 1
trigger10 = stateno = 205
trigger11 = movecontact = 1
trigger11 = stateno = 405

;---------------------------------------------------------------------------
;Jump X
[State -1]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jump Up Y
[State -1]
type = ChangeState
value = 607
triggerall = vel X = 0
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = p2statetype = A
trigger2 = movecontact = 1
trigger2 = stateno = 600
trigger3 = p2statetype = A
trigger3 = movecontact = 1
trigger3 = stateno = 604

;---------------------------------------------------------------------------
;Jump Y
[State -1]
type = ChangeState
value = 601
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = p2statetype = A
trigger2 = movecontact = 1
trigger2 = stateno = 600
trigger3 = p2statetype = A
trigger3 = movecontact = 1
trigger3 = stateno = 604

;---------------------------------------------------------------------------
;Jump Z
[State -1]
type = ChangeState
value = 602
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = p2statetype = A
trigger2 = movecontact = 1
trigger2 = stateno = 600
trigger3 = p2statetype = A
trigger3 = movecontact = 1
trigger3 = stateno = 601
trigger4 = p2statetype = A
trigger4 = movecontact = 1
trigger4 = stateno = 604
trigger5 = p2statetype = A
trigger5 = movecontact = 1
trigger5 = stateno = 605
trigger6 = p2statetype = A
trigger6 = movecontact = 1
trigger6 = stateno = 607
trigger7 = p2statetype = A
trigger7 = movecontact = 1
trigger7 = stateno = 608

;---------------------------------------------------------------------------
;Jump A
[State -1]
type = ChangeState
value = 604
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = p2statetype = A
trigger2 = movecontact = 1
trigger2 = stateno = 600

;---------------------------------------------------------------------------
;Jump Up B
[State -1]
type = ChangeState
value = 608
triggerall = vel X = 0
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = p2statetype = A
trigger2 = movecontact = 1
trigger2 = stateno = 600
trigger3 = p2statetype = A
trigger3 = movecontact = 1
trigger3 = stateno = 601
trigger4 = p2statetype = A
trigger4 = movecontact = 1
trigger4 = stateno = 602
trigger5 = p2statetype = A
trigger5 = movecontact = 1
trigger5 = stateno = 604
trigger6 = p2statetype = A
trigger6 = movecontact = 1
trigger6 = stateno = 607

;---------------------------------------------------------------------------
;Jump B
[State -1]
type = ChangeState
value = 605
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = p2statetype = A
trigger2 = movecontact = 1
trigger2 = stateno = 600
trigger3 = p2statetype = A
trigger3 = movecontact = 1
trigger3 = stateno = 601
trigger4 = p2statetype = A
trigger4 = movecontact = 1
trigger4 = stateno = 602
trigger5 = p2statetype = A
trigger5 = movecontact = 1
trigger5 = stateno = 604
trigger6 = p2statetype = A
trigger6 = movecontact = 1
trigger6 = stateno = 607

;---------------------------------------------------------------------------
;Jump C
[State -1]
type = ChangeState
value = 606
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = p2statetype = A
trigger2 = movecontact = 1
trigger2 = stateno = 600
trigger3 = p2statetype = A
trigger3 = movecontact = 1
trigger3 = stateno = 601
trigger4 = p2statetype = A
trigger4 = movecontact = 1
trigger4 = stateno = 604
trigger5 = p2statetype = A
trigger5 = movecontact = 1
trigger5 = stateno = 605
trigger6 = p2statetype = A
trigger6 = movecontact = 1
trigger6 = stateno = 607
trigger7 = p2statetype = A
trigger7 = movecontact = 1
trigger7 = stateno = 608

;---------------------------------------------------------------------------
Taunt
[State -1]
type = ChangeState
value = 195
triggerall = command = "s"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
